@@ -1,6 +1,7 @@
 use strict;
 package CPAN::Reporter::Config;
-our $VERSION = '1.2009'; # VERSION
+
+our $VERSION = '1.2014';
 
 use Config::Tiny 2.08 ();
 use File::Glob ();
@@ -292,6 +293,15 @@ HERE
     debug => {
         default => undef,
     },
+    retry_submission => {
+        default => undef,
+    },
+    '_store_problems_in_dir' => { #experimental
+        default => undef,
+    },
+    '_problem_log' => { #experimental
+        default => undef,
+    },
 );
 
 sub _config_spec { return %option_specs }
@@ -653,13 +663,15 @@ sub _validate_skipfile {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 CPAN::Reporter::Config - Config file options for CPAN::Reporter
 
 =head1 VERSION
 
-version 1.2009
+version 1.2014
 
 =head1 SYNOPSIS
 
@@ -847,7 +859,7 @@ C<<< inactivity_timeout >>> is not set, then any commands executed by CPAN::Repo
 will be halted after this many seconds; useful for unattended smoke testing
 to stop after some amount of time; generally, this should be large --
 900 seconds or more -- as some distributions' tests take quite a long time to
-run.  On MSWin32, L<Win32::Job> is a needed and trying to kill a processes may
+run.  On MSWin32, L<Win32::Job> is a needed and trying to kill a process may
 actually deadlock in some situations -- so use at your own risk.
 
 =item *
@@ -858,6 +870,11 @@ Test::Reporter will use environment variables C<<< VISUAL >>>, C<<< EDITOR >>> o
 
 =item *
 
+C<<< retry_submission >>> -- if greater than zero, CPAN::Reporter will try to
+resend the report after a few seconds in case the first attempt fails.
+
+=item *
+
 C<<< send_duplicates = <grade:action> ... >>> -- should duplicates of previous
 reports be sent, regardless of C<<< send_report >>>? (default:no)
 
